@@ -12,6 +12,9 @@ from time import perf_counter
 from typing import Any, Dict, List, Optional, Set, Tuple
 import chardet
 import pandas as pd
+from mitosheet.code_chunks.code_chunk import CodeChunk
+from mitosheet.code_chunks.step_performers.import_steps.simple_import_code_chunk import SimpleImportCodeChunk
+from mitosheet.step_performers.utils import get_param
 
 from mitosheet.utils import get_valid_dataframe_names
 from mitosheet.errors import make_is_directory_error
@@ -35,25 +38,10 @@ class SimpleImportStepPerformer(StepPerformer):
         return 'simple_import'
 
     @classmethod
-    def step_display_name(cls) -> str:
-        return 'Imported CSV Files'
-    
-    @classmethod
-    def step_event_type(cls) -> str:
-        return 'simple_import_edit'
+    def execute(cls, prev_state: State, params: Dict[str, Any]) -> Tuple[State, Optional[Dict[str, Any]]]:
+        file_names: List[str] = get_param(params, 'file_names')
+        use_deprecated_id_algorithm: bool = get_param(params, 'use_deprecated_id_algorithm') if get_param(params, 'use_deprecated_id_algorithm') else False
 
-    @classmethod
-    def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
-        return params
-
-    @classmethod
-    def execute( # type: ignore
-        cls,
-        prev_state: State,
-        file_names: List[str],
-        use_deprecated_id_algorithm: bool=False,
-        **params
-    ) -> Tuple[State, Optional[Dict[str, Any]]]:
         # If any of the files are directories, we throw an error to let
         # the user know
         for file_name in file_names:
@@ -61,7 +49,7 @@ class SimpleImportStepPerformer(StepPerformer):
                 raise make_is_directory_error(file_name)
 
         # Create a new step
-        post_state = copy(prev_state)
+        post_state = prev_state.copy()
 
         file_delimeters = []
         file_encodings = []
@@ -95,69 +83,20 @@ class SimpleImportStepPerformer(StepPerformer):
         }
 
     @classmethod
-    def transpile( # type: ignore
+    def transpile(
         cls,
         prev_state: State,
         post_state: State,
+        params: Dict[str, Any],
         execution_data: Optional[Dict[str, Any]],
-        file_names: List[str],
-        use_deprecated_id_algorithm: bool=False,
-    ) -> List[str]:
-        code = ['import pandas as pd']
-
-        index = 0
-        for file_name, df_name in zip(file_names, post_state.df_names[len(post_state.df_names) - len(file_names):]):
-
-            delimeter = execution_data['file_delimeters'][index] if execution_data is not None else None
-            encoding = execution_data['file_encodings'][index] if execution_data is not None else None
-
-            code.append(
-                generate_read_csv_code(file_name, df_name, delimeter, encoding)
-            )
-            
-            index += 1
-
-        return code
-
-    @classmethod
-    def describe( # type: ignore
-        cls,
-        file_names: List[str],
-        use_deprecated_id_algorithm: bool=False,
-        df_names=None,
-        **params
-    ) -> str:
-        return f'Imported {", ".join(file_names)}'
+    ) -> List[CodeChunk]:
+        return [
+            SimpleImportCodeChunk(prev_state, post_state, params, execution_data)
+        ]
     
     @classmethod
-    def get_modified_dataframe_indexes( # type: ignore
-        cls, 
-        file_names: List[str],
-        use_deprecated_id_algorithm: bool=False,
-        **params
-    ) -> Set[int]:
-        return {-1} # changes the new dataframe(s - there might be multiple made in this step)
-
-
-def generate_read_csv_code(file_name: str, df_name: str, delimeter: str, encoding: str) -> str:
-    """
-    Helper function for generating minimal read_csv code 
-    depending on the delimeter and the encoding of a file
-    """
-    if encoding != 'default' and delimeter != ',':
-        # If there is a non comma delimieter and an encoding, we use both.
-        # NOTE: we add a r in front of the string so that it is a raw string
-        # and file slashes are not interpreted as a unicode sequence
-        return f'{df_name} = pd.read_csv(r\'{file_name}\', sep=\'{delimeter}\', encoding=\'{encoding}\')'
-    elif encoding != 'default':
-        # If there is a comma delimieter and an encoding, we set the encoding
-        return f'{df_name} = pd.read_csv(r\'{file_name}\', encoding=\'{encoding}\')'
-    elif delimeter != ',':
-        # If there is a delimeter for this file, we use it
-        return f'{df_name} = pd.read_csv(r\'{file_name}\', sep=\'{delimeter}\')'
-    else:
-        # We don't add or encoding if they are the Default.
-        return f'{df_name} = pd.read_csv(r\'{file_name}\')'
+    def get_modified_dataframe_indexes(cls, params: Dict[str, Any]) -> Set[int]:
+        return {-1}
 
 
 def read_csv_get_delimeter_and_encoding(file_name: str) -> Tuple[pd.DataFrame, str, str]:
