@@ -310,6 +310,33 @@ class MitoWidgetTestWrapper:
             }
         )
 
+    @check_transpiled_code_after_call
+    def split_text_to_columns(
+            self, 
+            sheet_index: int,
+            column_header: ColumnHeader,
+            delimiters: List[str],
+            new_column_header_suffix: str
+        ) -> bool:
+
+        column_id = self.mito_widget.steps_manager.curr_step.get_column_id_by_header(sheet_index, column_header)
+
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'split_text_to_columns_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'sheet_index': sheet_index,
+                    'column_id': column_id,
+                    'delimiters': delimiters,
+                    'new_column_header_suffix': new_column_header_suffix
+                }
+            }
+        )
+
     @check_transpiled_code_after_call
     def drop_duplicates(
             self, 
@@ -1077,4 +1104,4 @@ def make_multi_index_header_df(data: Dict[Union[str, int], List[Any]], column_he
     df.columns = pd.MultiIndex.from_tuples(final_column_headers)
     if index is not None:
         df.index = index
-    return df
+    return df
\ No newline at end of file
