@@ -7,9 +7,10 @@
 Contains helpful utility functions
 """
 import json
+import numbers
 import re
 import uuid
-from typing import Any, Dict, List, Optional, Set, Tuple
+from typing import Any, Dict, List, Optional, Set, Tuple, Union
 from mitosheet.types import ColumnHeader, ColumnID
 
 import numpy as np
@@ -21,7 +22,7 @@ from mitosheet.sheet_functions.types.utils import get_float_dt_td_columns
 # We only send the first 1500 rows of a dataframe; note that this
 # must match this variable defined on the front-end
 MAX_ROWS = 1_500
-
+MAX_COLUMNS = 1_500
 
 def get_first_unused_dataframe_name(existing_df_names: List[str], new_dataframe_name: str) -> str:
     """
@@ -106,8 +107,9 @@ def dfs_to_array_for_json(
                     column_filters_array[sheet_index],
                     column_ids.column_header_to_column_id[sheet_index],
                     column_format_types[sheet_index],
-                    # We only send the first 1500 rows, and this must 
+                    # We only send the first 1500 rows and 1500 columns
                     max_length=MAX_ROWS,
+                    max_columns=MAX_COLUMNS
                 ) 
             )
         else:
@@ -124,10 +126,11 @@ def df_to_json_dumpsable(
         column_filters: Dict[ColumnID, Any],
         column_headers_to_column_ids: Dict[ColumnHeader, ColumnID],
         column_format_types: Dict[ColumnID, Dict[ColumnID, str]],
-        max_length: Optional[int]=MAX_ROWS, # How many items you want to display
+        max_length: Optional[int]=MAX_ROWS, # How many items you want to display. None when using this function to get unique value counts
+        max_columns: int=MAX_COLUMNS # How many columns you want to display. Unlike max_length, this is always defined
     ) -> Dict[str, Any]:
     """
-    Returns a dataframe represented in a way that can be turned into a 
+    Returns a dataframe and other metadata represented in a way that can be turned into a 
     JSON object with json.dumps.
 
     Should follow the format:
@@ -141,6 +144,7 @@ def df_to_json_dumpsable(
             columnHeader: (string | number);
             columnDtype: string;
             columnData: (string | number)[];
+            columnFormatTypeObj: FormatTypeObj;
         }[];
         columnIDsMap: ColumnIDsMap;
         columnSpreadsheetCodeMap: Record<string, string>;
@@ -159,6 +163,67 @@ def df_to_json_dumpsable(
         # we only show the first max_length rows!
         df = original_df.head(n=max_length if max_length else num_rows).copy(deep=True)
 
+    # we only show the first max_columns columns!
+    df = df.iloc[: , :max_columns]
+
+    json_obj = convert_df_to_parsed_json(df)
+
+    final_data = []
+    column_dtype_map = {}
+    for column_index, column_header in enumerate(json_obj['columns']):
+        # Because turning the headers to json takes multi-index columns and converts
+        # them into lists, we need to turn them back to tuples so we can index into the
+        # mappings appropriately
+        if isinstance(column_header, list):
+            column_header = tuple(column_header)
+
+        column_id = column_headers_to_column_ids[column_header]
+
+        column_final_data = {
+            'columnID': column_id,
+            'columnHeader': column_header,
+            'columnDtype': str(original_df[column_header].dtype),
+            'columnData': [],
+            'columnFormatTypeObj': column_format_types[column_id],
+        }
+        column_dtype_map[column_id] = str(original_df[column_header].dtype)
+        for row in json_obj['data']:
+            column_final_data['columnData'].append(row[column_index])
+        
+        final_data.append(column_final_data)     
+    
+    return {
+        "dfName": df_name,
+        "dfSource": df_source,
+        'numRows': num_rows,
+        'numColumns': num_columns,
+        'data': final_data,
+        # NOTE: We make sure that all the maps are in the correct order, so things are easy on the
+        # front-end and we don't have to worry about sorting
+        'columnIDsMap': {
+            column_headers_to_column_ids[column_header]: column_header
+            for column_header in df.keys()
+        },
+        'columnSpreadsheetCodeMap': column_spreadsheet_code,
+        'columnFiltersMap': column_filters,
+        'columnDtypeMap': column_dtype_map,
+        'index': json_obj['index'],
+        'columnFormatTypeObjMap': column_format_types
+    }
+
+
+def get_row_data_array(df: pd.DataFrame) -> List[Any]:
+    """
+    Returns just the data of a dataframe in the 2d array format of [row idx][col idx]
+    """
+    json_obj = convert_df_to_parsed_json(df)
+    return json_obj['data']
+
+def convert_df_to_parsed_json(df: pd.DataFrame) -> Dict[str, Any]:
+    """
+    Returns a dataframe as a json object with the correct formatting
+    """
+
     float_columns, date_columns, timedelta_columns = get_float_dt_td_columns(df)
     # Second, we figure out which of the columns contain dates, and we
     # convert them to string columns (for formatting reasons).
@@ -187,47 +252,7 @@ def df_to_json_dumpsable(
             if e is None:
                 d[idx] = 'NaN'
 
-    final_data = []
-    column_dtype_map = {}
-    for column_index, column_header in enumerate(json_obj['columns']):
-        # Because turning the headers to json takes multi-index columns and converts
-        # them into lists, we need to turn them back to tuples so we can index into the
-        # mappings appropriately
-        if isinstance(column_header, list):
-            column_header = tuple(column_header)
-
-        column_id = column_headers_to_column_ids[column_header]
-
-        column_final_data = {
-            'columnID': column_id,
-            'columnHeader': column_header,
-            'columnDtype': str(original_df[column_header].dtype),
-            'columnData': []
-        }
-        column_dtype_map[column_id] = str(original_df[column_header].dtype)
-        for row in json_obj['data']:
-            column_final_data['columnData'].append(row[column_index])
-        
-        final_data.append(column_final_data)     
-    
-    return {
-        "dfName": df_name,
-        "dfSource": df_source,
-        'numRows': num_rows,
-        'numColumns': num_columns,
-        'data': final_data,
-        # NOTE: We make sure that all the maps are in the correct order, so things are easy on the
-        # front-end and we don't have to worry about sorting
-        'columnIDsMap': {
-            column_headers_to_column_ids[column_header]: column_header
-            for column_header in df.keys()
-        },
-        'columnSpreadsheetCodeMap': column_spreadsheet_code,
-        'columnFiltersMap': column_filters,
-        'columnDtypeMap': column_dtype_map,
-        'index': json_obj['index'],
-        'columnFormatTypeObjMap': column_format_types
-    }
+    return json_obj
 
 
 def get_random_id() -> str:
